# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class HTTPServiceProxyCreateParamPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disable_rewrite_rules': 'bool',
        'duration': 'str',
        'headers': 'str',
        'name': 'str',
        'project_id': 'str',
        'service_name': 'str',
        'service_namespace': 'str',
        'service_port': 'int',
        'setup_basic_auth': 'bool',
        'setup_dns': 'bool',
        'skip_cert_verification': 'bool',
        'svc_domain_id': 'str',
        'tls_endpoint': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'disable_rewrite_rules': 'disableRewriteRules',
        'duration': 'duration',
        'headers': 'headers',
        'name': 'name',
        'project_id': 'projectId',
        'service_name': 'serviceName',
        'service_namespace': 'serviceNamespace',
        'service_port': 'servicePort',
        'setup_basic_auth': 'setupBasicAuth',
        'setup_dns': 'setupDNS',
        'skip_cert_verification': 'skipCertVerification',
        'svc_domain_id': 'svcDomainId',
        'tls_endpoint': 'tlsEndpoint',
        'type': 'type'
    }

    def __init__(self, disable_rewrite_rules=None, duration=None, headers=None, name=None, project_id=None, service_name=None, service_namespace=None, service_port=None, setup_basic_auth=None, setup_dns=None, skip_cert_verification=None, svc_domain_id=None, tls_endpoint=None, type=None):  # noqa: E501
        """HTTPServiceProxyCreateParamPayload - a model defined in Swagger"""  # noqa: E501
        self._disable_rewrite_rules = None
        self._duration = None
        self._headers = None
        self._name = None
        self._project_id = None
        self._service_name = None
        self._service_namespace = None
        self._service_port = None
        self._setup_basic_auth = None
        self._setup_dns = None
        self._skip_cert_verification = None
        self._svc_domain_id = None
        self._tls_endpoint = None
        self._type = None
        self.discriminator = None
        self.disable_rewrite_rules = disable_rewrite_rules
        self.duration = duration
        if headers is not None:
            self.headers = headers
        self.name = name
        if project_id is not None:
            self.project_id = project_id
        self.service_name = service_name
        if service_namespace is not None:
            self.service_namespace = service_namespace
        self.service_port = service_port
        self.setup_basic_auth = setup_basic_auth
        self.setup_dns = setup_dns
        self.skip_cert_verification = skip_cert_verification
        self.svc_domain_id = svc_domain_id
        self.tls_endpoint = tls_endpoint
        self.type = type

    @property
    def disable_rewrite_rules(self):
        """Gets the disable_rewrite_rules of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        By default, a rewrite rule will be put in place to rewrite service URL path base to / set this flag to true to retain the URL path base.  # noqa: E501

        :return: The disable_rewrite_rules of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._disable_rewrite_rules

    @disable_rewrite_rules.setter
    def disable_rewrite_rules(self, disable_rewrite_rules):
        """Sets the disable_rewrite_rules of this HTTPServiceProxyCreateParamPayload.

        By default, a rewrite rule will be put in place to rewrite service URL path base to / set this flag to true to retain the URL path base.  # noqa: E501

        :param disable_rewrite_rules: The disable_rewrite_rules of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: bool
        """
        if disable_rewrite_rules is None:
            raise ValueError("Invalid value for `disable_rewrite_rules`, must not be `None`")  # noqa: E501

        self._disable_rewrite_rules = disable_rewrite_rules

    @property
    def duration(self):
        """Gets the duration of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        Duration of the http service proxy.  # noqa: E501

        :return: The duration of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this HTTPServiceProxyCreateParamPayload.

        Duration of the http service proxy.  # noqa: E501

        :param duration: The duration of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """
        if duration is None:
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501

        self._duration = duration

    @property
    def headers(self):
        """Gets the headers of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        JSON object representation of HTTP headers to overwrite. May be useful for (https) endpoint that require specific Host field for example.  # noqa: E501

        :return: The headers of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this HTTPServiceProxyCreateParamPayload.

        JSON object representation of HTTP headers to overwrite. May be useful for (https) endpoint that require specific Host field for example.  # noqa: E501

        :param headers: The headers of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """

        self._headers = headers

    @property
    def name(self):
        """Gets the name of this HTTPServiceProxyCreateParamPayload.  # noqa: E501


        :return: The name of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HTTPServiceProxyCreateParamPayload.


        :param name: The name of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this HTTPServiceProxyCreateParamPayload.  # noqa: E501


        :return: The project_id of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this HTTPServiceProxyCreateParamPayload.


        :param project_id: The project_id of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def service_name(self):
        """Gets the service_name of this HTTPServiceProxyCreateParamPayload.  # noqa: E501


        :return: The service_name of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """Sets the service_name of this HTTPServiceProxyCreateParamPayload.


        :param service_name: The service_name of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """
        if service_name is None:
            raise ValueError("Invalid value for `service_name`, must not be `None`")  # noqa: E501

        self._service_name = service_name

    @property
    def service_namespace(self):
        """Gets the service_namespace of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        Namespace of the http service, required when TYPE = SYSTEM  # noqa: E501

        :return: The service_namespace of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._service_namespace

    @service_namespace.setter
    def service_namespace(self, service_namespace):
        """Sets the service_namespace of this HTTPServiceProxyCreateParamPayload.

        Namespace of the http service, required when TYPE = SYSTEM  # noqa: E501

        :param service_namespace: The service_namespace of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """

        self._service_namespace = service_namespace

    @property
    def service_port(self):
        """Gets the service_port of this HTTPServiceProxyCreateParamPayload.  # noqa: E501


        :return: The service_port of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: int
        """
        return self._service_port

    @service_port.setter
    def service_port(self, service_port):
        """Sets the service_port of this HTTPServiceProxyCreateParamPayload.


        :param service_port: The service_port of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: int
        """
        if service_port is None:
            raise ValueError("Invalid value for `service_port`, must not be `None`")  # noqa: E501

        self._service_port = service_port

    @property
    def setup_basic_auth(self):
        """Gets the setup_basic_auth of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        Whether to setup basic auth to protect the endpoint  # noqa: E501

        :return: The setup_basic_auth of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._setup_basic_auth

    @setup_basic_auth.setter
    def setup_basic_auth(self, setup_basic_auth):
        """Sets the setup_basic_auth of this HTTPServiceProxyCreateParamPayload.

        Whether to setup basic auth to protect the endpoint  # noqa: E501

        :param setup_basic_auth: The setup_basic_auth of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: bool
        """
        if setup_basic_auth is None:
            raise ValueError("Invalid value for `setup_basic_auth`, must not be `None`")  # noqa: E501

        self._setup_basic_auth = setup_basic_auth

    @property
    def setup_dns(self):
        """Gets the setup_dns of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        Whether to setup DNS entry for this service. Default is false. Might be useful for services that do not work with URL path. However, bear in mind it may take several minutes for the DNS name to propagate/resolve.  # noqa: E501

        :return: The setup_dns of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._setup_dns

    @setup_dns.setter
    def setup_dns(self, setup_dns):
        """Sets the setup_dns of this HTTPServiceProxyCreateParamPayload.

        Whether to setup DNS entry for this service. Default is false. Might be useful for services that do not work with URL path. However, bear in mind it may take several minutes for the DNS name to propagate/resolve.  # noqa: E501

        :param setup_dns: The setup_dns of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: bool
        """
        if setup_dns is None:
            raise ValueError("Invalid value for `setup_dns`, must not be `None`")  # noqa: E501

        self._setup_dns = setup_dns

    @property
    def skip_cert_verification(self):
        """Gets the skip_cert_verification of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        Whether to skip TLS certification verification for endpoint. Only relevant when TLSEndpoint is true. This should be set to true if the endpoint is using a self-signed certificate.  # noqa: E501

        :return: The skip_cert_verification of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._skip_cert_verification

    @skip_cert_verification.setter
    def skip_cert_verification(self, skip_cert_verification):
        """Sets the skip_cert_verification of this HTTPServiceProxyCreateParamPayload.

        Whether to skip TLS certification verification for endpoint. Only relevant when TLSEndpoint is true. This should be set to true if the endpoint is using a self-signed certificate.  # noqa: E501

        :param skip_cert_verification: The skip_cert_verification of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: bool
        """
        if skip_cert_verification is None:
            raise ValueError("Invalid value for `skip_cert_verification`, must not be `None`")  # noqa: E501

        self._skip_cert_verification = skip_cert_verification

    @property
    def svc_domain_id(self):
        """Gets the svc_domain_id of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        ID of Service Domain to create the http service proxy  # noqa: E501

        :return: The svc_domain_id of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._svc_domain_id

    @svc_domain_id.setter
    def svc_domain_id(self, svc_domain_id):
        """Sets the svc_domain_id of this HTTPServiceProxyCreateParamPayload.

        ID of Service Domain to create the http service proxy  # noqa: E501

        :param svc_domain_id: The svc_domain_id of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """
        if svc_domain_id is None:
            raise ValueError("Invalid value for `svc_domain_id`, must not be `None`")  # noqa: E501

        self._svc_domain_id = svc_domain_id

    @property
    def tls_endpoint(self):
        """Gets the tls_endpoint of this HTTPServiceProxyCreateParamPayload.  # noqa: E501

        Whether the endpoint to proxy to is a TLS endpoint.  # noqa: E501

        :return: The tls_endpoint of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._tls_endpoint

    @tls_endpoint.setter
    def tls_endpoint(self, tls_endpoint):
        """Sets the tls_endpoint of this HTTPServiceProxyCreateParamPayload.

        Whether the endpoint to proxy to is a TLS endpoint.  # noqa: E501

        :param tls_endpoint: The tls_endpoint of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: bool
        """
        if tls_endpoint is None:
            raise ValueError("Invalid value for `tls_endpoint`, must not be `None`")  # noqa: E501

        self._tls_endpoint = tls_endpoint

    @property
    def type(self):
        """Gets the type of this HTTPServiceProxyCreateParamPayload.  # noqa: E501


        :return: The type of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this HTTPServiceProxyCreateParamPayload.


        :param type: The type of this HTTPServiceProxyCreateParamPayload.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["SYSTEM", "PROJECT", "CUSTOM"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HTTPServiceProxyCreateParamPayload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HTTPServiceProxyCreateParamPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Certificates(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ca_certificate': 'str',
        'certificate': 'str',
        'private_key': 'str'
    }

    attribute_map = {
        'ca_certificate': 'CACertificate',
        'certificate': 'certificate',
        'private_key': 'privateKey'
    }

    def __init__(self, ca_certificate=None, certificate=None, private_key=None):  # noqa: E501
        """Certificates - a model defined in Swagger"""  # noqa: E501
        self._ca_certificate = None
        self._certificate = None
        self._private_key = None
        self.discriminator = None
        self.ca_certificate = ca_certificate
        self.certificate = certificate
        self.private_key = private_key

    @property
    def ca_certificate(self):
        """Gets the ca_certificate of this Certificates.  # noqa: E501

        Root CA certificate that signed the device certificate.  # noqa: E501

        :return: The ca_certificate of this Certificates.  # noqa: E501
        :rtype: str
        """
        return self._ca_certificate

    @ca_certificate.setter
    def ca_certificate(self, ca_certificate):
        """Sets the ca_certificate of this Certificates.

        Root CA certificate that signed the device certificate.  # noqa: E501

        :param ca_certificate: The ca_certificate of this Certificates.  # noqa: E501
        :type: str
        """
        if ca_certificate is None:
            raise ValueError("Invalid value for `ca_certificate`, must not be `None`")  # noqa: E501

        self._ca_certificate = ca_certificate

    @property
    def certificate(self):
        """Gets the certificate of this Certificates.  # noqa: E501

        Certificate for a device.  # noqa: E501

        :return: The certificate of this Certificates.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this Certificates.

        Certificate for a device.  # noqa: E501

        :param certificate: The certificate of this Certificates.  # noqa: E501
        :type: str
        """
        if certificate is None:
            raise ValueError("Invalid value for `certificate`, must not be `None`")  # noqa: E501

        self._certificate = certificate

    @property
    def private_key(self):
        """Gets the private_key of this Certificates.  # noqa: E501

        Encrypted private key corresponding to the certificate.  # noqa: E501

        :return: The private_key of this Certificates.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this Certificates.

        Encrypted private key corresponding to the certificate.  # noqa: E501

        :param private_key: The private_key of this Certificates.  # noqa: E501
        :type: str
        """
        if private_key is None:
            raise ValueError("Invalid value for `private_key`, must not be `None`")  # noqa: E501

        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Certificates, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Certificates):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.log_collector_cloudwatch import LogCollectorCloudwatch  # noqa: F401,E501
from kps_api.models.log_collector_destination import LogCollectorDestination  # noqa: F401,E501
from kps_api.models.log_collector_kinesis import LogCollectorKinesis  # noqa: F401,E501
from kps_api.models.log_collector_sources import LogCollectorSources  # noqa: F401,E501
from kps_api.models.log_collector_stackdriver import LogCollectorStackdriver  # noqa: F401,E501
from kps_api.models.log_collector_status import LogCollectorStatus  # noqa: F401,E501
from kps_api.models.log_collector_type import LogCollectorType  # noqa: F401,E501


class LogCollector(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_creds_id': 'str',
        'cloudwatch_details': 'LogCollectorCloudwatch',
        'code': 'str',
        'dest': 'LogCollectorDestination',
        'id': 'str',
        'kinesis_details': 'LogCollectorKinesis',
        'name': 'str',
        'project_id': 'str',
        'sources': 'LogCollectorSources',
        'stackdriver_details': 'LogCollectorStackdriver',
        'state': 'LogCollectorStatus',
        'type': 'LogCollectorType'
    }

    attribute_map = {
        'cloud_creds_id': 'cloudCredsID',
        'cloudwatch_details': 'cloudwatchDetails',
        'code': 'code',
        'dest': 'dest',
        'id': 'id',
        'kinesis_details': 'kinesisDetails',
        'name': 'name',
        'project_id': 'projectId',
        'sources': 'sources',
        'stackdriver_details': 'stackdriverDetails',
        'state': 'state',
        'type': 'type'
    }

    def __init__(self, cloud_creds_id=None, cloudwatch_details=None, code=None, dest=None, id=None, kinesis_details=None, name=None, project_id=None, sources=None, stackdriver_details=None, state=None, type=None):  # noqa: E501
        """LogCollector - a model defined in Swagger"""  # noqa: E501
        self._cloud_creds_id = None
        self._cloudwatch_details = None
        self._code = None
        self._dest = None
        self._id = None
        self._kinesis_details = None
        self._name = None
        self._project_id = None
        self._sources = None
        self._stackdriver_details = None
        self._state = None
        self._type = None
        self.discriminator = None
        self.cloud_creds_id = cloud_creds_id
        if cloudwatch_details is not None:
            self.cloudwatch_details = cloudwatch_details
        if code is not None:
            self.code = code
        self.dest = dest
        if id is not None:
            self.id = id
        if kinesis_details is not None:
            self.kinesis_details = kinesis_details
        self.name = name
        if project_id is not None:
            self.project_id = project_id
        self.sources = sources
        if stackdriver_details is not None:
            self.stackdriver_details = stackdriver_details
        self.state = state
        self.type = type

    @property
    def cloud_creds_id(self):
        """Gets the cloud_creds_id of this LogCollector.  # noqa: E501

        CloudCreds id. Destination id for the cloud (should match with the CloudDestinationType)  # noqa: E501

        :return: The cloud_creds_id of this LogCollector.  # noqa: E501
        :rtype: str
        """
        return self._cloud_creds_id

    @cloud_creds_id.setter
    def cloud_creds_id(self, cloud_creds_id):
        """Sets the cloud_creds_id of this LogCollector.

        CloudCreds id. Destination id for the cloud (should match with the CloudDestinationType)  # noqa: E501

        :param cloud_creds_id: The cloud_creds_id of this LogCollector.  # noqa: E501
        :type: str
        """
        if cloud_creds_id is None:
            raise ValueError("Invalid value for `cloud_creds_id`, must not be `None`")  # noqa: E501

        self._cloud_creds_id = cloud_creds_id

    @property
    def cloudwatch_details(self):
        """Gets the cloudwatch_details of this LogCollector.  # noqa: E501


        :return: The cloudwatch_details of this LogCollector.  # noqa: E501
        :rtype: LogCollectorCloudwatch
        """
        return self._cloudwatch_details

    @cloudwatch_details.setter
    def cloudwatch_details(self, cloudwatch_details):
        """Sets the cloudwatch_details of this LogCollector.


        :param cloudwatch_details: The cloudwatch_details of this LogCollector.  # noqa: E501
        :type: LogCollectorCloudwatch
        """

        self._cloudwatch_details = cloudwatch_details

    @property
    def code(self):
        """Gets the code of this LogCollector.  # noqa: E501

        A code to modify logs during collection Log stream modifications (script source code)  # noqa: E501

        :return: The code of this LogCollector.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this LogCollector.

        A code to modify logs during collection Log stream modifications (script source code)  # noqa: E501

        :param code: The code of this LogCollector.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def dest(self):
        """Gets the dest of this LogCollector.  # noqa: E501


        :return: The dest of this LogCollector.  # noqa: E501
        :rtype: LogCollectorDestination
        """
        return self._dest

    @dest.setter
    def dest(self, dest):
        """Sets the dest of this LogCollector.


        :param dest: The dest of this LogCollector.  # noqa: E501
        :type: LogCollectorDestination
        """
        if dest is None:
            raise ValueError("Invalid value for `dest`, must not be `None`")  # noqa: E501

        self._dest = dest

    @property
    def id(self):
        """Gets the id of this LogCollector.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this LogCollector.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LogCollector.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this LogCollector.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def kinesis_details(self):
        """Gets the kinesis_details of this LogCollector.  # noqa: E501


        :return: The kinesis_details of this LogCollector.  # noqa: E501
        :rtype: LogCollectorKinesis
        """
        return self._kinesis_details

    @kinesis_details.setter
    def kinesis_details(self, kinesis_details):
        """Sets the kinesis_details of this LogCollector.


        :param kinesis_details: The kinesis_details of this LogCollector.  # noqa: E501
        :type: LogCollectorKinesis
        """

        self._kinesis_details = kinesis_details

    @property
    def name(self):
        """Gets the name of this LogCollector.  # noqa: E501

        Name of the LogCollector. Visible by UI only  # noqa: E501

        :return: The name of this LogCollector.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LogCollector.

        Name of the LogCollector. Visible by UI only  # noqa: E501

        :param name: The name of this LogCollector.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this LogCollector.  # noqa: E501

        ID of parent project. This should be required for PROJECT log collectors.  # noqa: E501

        :return: The project_id of this LogCollector.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this LogCollector.

        ID of parent project. This should be required for PROJECT log collectors.  # noqa: E501

        :param project_id: The project_id of this LogCollector.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def sources(self):
        """Gets the sources of this LogCollector.  # noqa: E501


        :return: The sources of this LogCollector.  # noqa: E501
        :rtype: LogCollectorSources
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """Sets the sources of this LogCollector.


        :param sources: The sources of this LogCollector.  # noqa: E501
        :type: LogCollectorSources
        """
        if sources is None:
            raise ValueError("Invalid value for `sources`, must not be `None`")  # noqa: E501

        self._sources = sources

    @property
    def stackdriver_details(self):
        """Gets the stackdriver_details of this LogCollector.  # noqa: E501


        :return: The stackdriver_details of this LogCollector.  # noqa: E501
        :rtype: LogCollectorStackdriver
        """
        return self._stackdriver_details

    @stackdriver_details.setter
    def stackdriver_details(self, stackdriver_details):
        """Sets the stackdriver_details of this LogCollector.


        :param stackdriver_details: The stackdriver_details of this LogCollector.  # noqa: E501
        :type: LogCollectorStackdriver
        """

        self._stackdriver_details = stackdriver_details

    @property
    def state(self):
        """Gets the state of this LogCollector.  # noqa: E501


        :return: The state of this LogCollector.  # noqa: E501
        :rtype: LogCollectorStatus
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this LogCollector.


        :param state: The state of this LogCollector.  # noqa: E501
        :type: LogCollectorStatus
        """
        if state is None:
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def type(self):
        """Gets the type of this LogCollector.  # noqa: E501


        :return: The type of this LogCollector.  # noqa: E501
        :rtype: LogCollectorType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LogCollector.


        :param type: The type of this LogCollector.  # noqa: E501
        :type: LogCollectorType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LogCollector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogCollector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class HTTPServiceProxyUpdateParamPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disable_rewrite_rules': 'bool',
        'duration': 'str',
        'headers': 'str',
        'name': 'str',
        'setup_dns': 'bool',
        'skip_cert_verification': 'bool',
        'tls_endpoint': 'bool'
    }

    attribute_map = {
        'disable_rewrite_rules': 'disableRewriteRules',
        'duration': 'duration',
        'headers': 'headers',
        'name': 'name',
        'setup_dns': 'setupDNS',
        'skip_cert_verification': 'skipCertVerification',
        'tls_endpoint': 'tlsEndpoint'
    }

    def __init__(self, disable_rewrite_rules=None, duration=None, headers=None, name=None, setup_dns=None, skip_cert_verification=None, tls_endpoint=None):  # noqa: E501
        """HTTPServiceProxyUpdateParamPayload - a model defined in Swagger"""  # noqa: E501
        self._disable_rewrite_rules = None
        self._duration = None
        self._headers = None
        self._name = None
        self._setup_dns = None
        self._skip_cert_verification = None
        self._tls_endpoint = None
        self.discriminator = None
        if disable_rewrite_rules is not None:
            self.disable_rewrite_rules = disable_rewrite_rules
        if duration is not None:
            self.duration = duration
        if headers is not None:
            self.headers = headers
        if name is not None:
            self.name = name
        self.setup_dns = setup_dns
        self.skip_cert_verification = skip_cert_verification
        self.tls_endpoint = tls_endpoint

    @property
    def disable_rewrite_rules(self):
        """Gets the disable_rewrite_rules of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501

        By default, a rewrite rule will be put in place to rewrite service URL path base to / set this flag to true to retain the URL path base.  # noqa: E501

        :return: The disable_rewrite_rules of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._disable_rewrite_rules

    @disable_rewrite_rules.setter
    def disable_rewrite_rules(self, disable_rewrite_rules):
        """Sets the disable_rewrite_rules of this HTTPServiceProxyUpdateParamPayload.

        By default, a rewrite rule will be put in place to rewrite service URL path base to / set this flag to true to retain the URL path base.  # noqa: E501

        :param disable_rewrite_rules: The disable_rewrite_rules of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: bool
        """

        self._disable_rewrite_rules = disable_rewrite_rules

    @property
    def duration(self):
        """Gets the duration of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501

        Duration of the http service proxy.  # noqa: E501

        :return: The duration of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this HTTPServiceProxyUpdateParamPayload.

        Duration of the http service proxy.  # noqa: E501

        :param duration: The duration of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def headers(self):
        """Gets the headers of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501

        JSON object representation of HTTP headers to overwrite. May be useful for (https) endpoint that require specific Host field for example.  # noqa: E501

        :return: The headers of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this HTTPServiceProxyUpdateParamPayload.

        JSON object representation of HTTP headers to overwrite. May be useful for (https) endpoint that require specific Host field for example.  # noqa: E501

        :param headers: The headers of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: str
        """

        self._headers = headers

    @property
    def name(self):
        """Gets the name of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501


        :return: The name of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HTTPServiceProxyUpdateParamPayload.


        :param name: The name of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def setup_dns(self):
        """Gets the setup_dns of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501

        Whether to setup DNS entry for this service. Default is false. Might be useful for services that do not work with URL path. However, bear in mind it may take several minutes for the DNS name to propagate/resolve.  # noqa: E501

        :return: The setup_dns of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._setup_dns

    @setup_dns.setter
    def setup_dns(self, setup_dns):
        """Sets the setup_dns of this HTTPServiceProxyUpdateParamPayload.

        Whether to setup DNS entry for this service. Default is false. Might be useful for services that do not work with URL path. However, bear in mind it may take several minutes for the DNS name to propagate/resolve.  # noqa: E501

        :param setup_dns: The setup_dns of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: bool
        """
        if setup_dns is None:
            raise ValueError("Invalid value for `setup_dns`, must not be `None`")  # noqa: E501

        self._setup_dns = setup_dns

    @property
    def skip_cert_verification(self):
        """Gets the skip_cert_verification of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501

        Whether to skip TLS certification verification for endpoint. Only relevant when TLSEndpoint is true. This should be set to true if the endpoint is using a self-signed certificate.  # noqa: E501

        :return: The skip_cert_verification of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._skip_cert_verification

    @skip_cert_verification.setter
    def skip_cert_verification(self, skip_cert_verification):
        """Sets the skip_cert_verification of this HTTPServiceProxyUpdateParamPayload.

        Whether to skip TLS certification verification for endpoint. Only relevant when TLSEndpoint is true. This should be set to true if the endpoint is using a self-signed certificate.  # noqa: E501

        :param skip_cert_verification: The skip_cert_verification of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: bool
        """
        if skip_cert_verification is None:
            raise ValueError("Invalid value for `skip_cert_verification`, must not be `None`")  # noqa: E501

        self._skip_cert_verification = skip_cert_verification

    @property
    def tls_endpoint(self):
        """Gets the tls_endpoint of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501

        Whether the endpoint to proxy to is a TLS endpoint.  # noqa: E501

        :return: The tls_endpoint of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :rtype: bool
        """
        return self._tls_endpoint

    @tls_endpoint.setter
    def tls_endpoint(self, tls_endpoint):
        """Sets the tls_endpoint of this HTTPServiceProxyUpdateParamPayload.

        Whether the endpoint to proxy to is a TLS endpoint.  # noqa: E501

        :param tls_endpoint: The tls_endpoint of this HTTPServiceProxyUpdateParamPayload.  # noqa: E501
        :type: bool
        """
        if tls_endpoint is None:
            raise ValueError("Invalid value for `tls_endpoint`, must not be `None`")  # noqa: E501

        self._tls_endpoint = tls_endpoint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HTTPServiceProxyUpdateParamPayload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HTTPServiceProxyUpdateParamPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.object_meta import ObjectMeta  # noqa: F401,E501


class IstioTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'kind': 'str',
        'metadata': 'ObjectMeta',
        'spec': 'object'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'kind': 'kind',
        'metadata': 'metadata',
        'spec': 'spec'
    }

    def __init__(self, api_version=None, kind=None, metadata=None, spec=None):  # noqa: E501
        """IstioTemplate - a model defined in Swagger"""  # noqa: E501
        self._api_version = None
        self._kind = None
        self._metadata = None
        self._spec = None
        self.discriminator = None
        if api_version is not None:
            self.api_version = api_version
        if kind is not None:
            self.kind = kind
        if metadata is not None:
            self.metadata = metadata
        if spec is not None:
            self.spec = spec

    @property
    def api_version(self):
        """Gets the api_version of this IstioTemplate.  # noqa: E501

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources +optional  # noqa: E501

        :return: The api_version of this IstioTemplate.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this IstioTemplate.

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources +optional  # noqa: E501

        :param api_version: The api_version of this IstioTemplate.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def kind(self):
        """Gets the kind of this IstioTemplate.  # noqa: E501

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds +optional  # noqa: E501

        :return: The kind of this IstioTemplate.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this IstioTemplate.

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds +optional  # noqa: E501

        :param kind: The kind of this IstioTemplate.  # noqa: E501
        :type: str
        """

        self._kind = kind

    @property
    def metadata(self):
        """Gets the metadata of this IstioTemplate.  # noqa: E501


        :return: The metadata of this IstioTemplate.  # noqa: E501
        :rtype: ObjectMeta
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this IstioTemplate.


        :param metadata: The metadata of this IstioTemplate.  # noqa: E501
        :type: ObjectMeta
        """

        self._metadata = metadata

    @property
    def spec(self):
        """Gets the spec of this IstioTemplate.  # noqa: E501


        :return: The spec of this IstioTemplate.  # noqa: E501
        :rtype: object
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this IstioTemplate.


        :param spec: The spec of this IstioTemplate.  # noqa: E501
        :type: object
        """

        self._spec = spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IstioTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IstioTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ExecuteEdgeUpgradeData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'str',
        'docker_login': 'str',
        'edge_id': 'str',
        'id': 'str',
        'release': 'str',
        'upgrade_url': 'str'
    }

    attribute_map = {
        'data': 'data',
        'docker_login': 'dockerLogin',
        'edge_id': 'edgeID',
        'id': 'id',
        'release': 'release',
        'upgrade_url': 'upgradeURL'
    }

    def __init__(self, data=None, docker_login=None, edge_id=None, id=None, release=None, upgrade_url=None):  # noqa: E501
        """ExecuteEdgeUpgradeData - a model defined in Swagger"""  # noqa: E501
        self._data = None
        self._docker_login = None
        self._edge_id = None
        self._id = None
        self._release = None
        self._upgrade_url = None
        self.discriminator = None
        self.data = data
        self.docker_login = docker_login
        self.edge_id = edge_id
        if id is not None:
            self.id = id
        self.release = release
        self.upgrade_url = upgrade_url

    @property
    def data(self):
        """Gets the data of this ExecuteEdgeUpgradeData.  # noqa: E501

        Data for the execute edge upgrade.  # noqa: E501

        :return: The data of this ExecuteEdgeUpgradeData.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ExecuteEdgeUpgradeData.

        Data for the execute edge upgrade.  # noqa: E501

        :param data: The data of this ExecuteEdgeUpgradeData.  # noqa: E501
        :type: str
        """
        if data is None:
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def docker_login(self):
        """Gets the docker_login of this ExecuteEdgeUpgradeData.  # noqa: E501

        Docker login command  # noqa: E501

        :return: The docker_login of this ExecuteEdgeUpgradeData.  # noqa: E501
        :rtype: str
        """
        return self._docker_login

    @docker_login.setter
    def docker_login(self, docker_login):
        """Sets the docker_login of this ExecuteEdgeUpgradeData.

        Docker login command  # noqa: E501

        :param docker_login: The docker_login of this ExecuteEdgeUpgradeData.  # noqa: E501
        :type: str
        """
        if docker_login is None:
            raise ValueError("Invalid value for `docker_login`, must not be `None`")  # noqa: E501

        self._docker_login = docker_login

    @property
    def edge_id(self):
        """Gets the edge_id of this ExecuteEdgeUpgradeData.  # noqa: E501

        EdgeID. ID of the specific edge to upgrade.  # noqa: E501

        :return: The edge_id of this ExecuteEdgeUpgradeData.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this ExecuteEdgeUpgradeData.

        EdgeID. ID of the specific edge to upgrade.  # noqa: E501

        :param edge_id: The edge_id of this ExecuteEdgeUpgradeData.  # noqa: E501
        :type: str
        """
        if edge_id is None:
            raise ValueError("Invalid value for `edge_id`, must not be `None`")  # noqa: E501

        self._edge_id = edge_id

    @property
    def id(self):
        """Gets the id of this ExecuteEdgeUpgradeData.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this ExecuteEdgeUpgradeData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ExecuteEdgeUpgradeData.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this ExecuteEdgeUpgradeData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def release(self):
        """Gets the release of this ExecuteEdgeUpgradeData.  # noqa: E501

        Release for execute edge upgrade.  # noqa: E501

        :return: The release of this ExecuteEdgeUpgradeData.  # noqa: E501
        :rtype: str
        """
        return self._release

    @release.setter
    def release(self, release):
        """Sets the release of this ExecuteEdgeUpgradeData.

        Release for execute edge upgrade.  # noqa: E501

        :param release: The release of this ExecuteEdgeUpgradeData.  # noqa: E501
        :type: str
        """
        if release is None:
            raise ValueError("Invalid value for `release`, must not be `None`")  # noqa: E501

        self._release = release

    @property
    def upgrade_url(self):
        """Gets the upgrade_url of this ExecuteEdgeUpgradeData.  # noqa: E501

        URL for the edge to get the upgrade from  # noqa: E501

        :return: The upgrade_url of this ExecuteEdgeUpgradeData.  # noqa: E501
        :rtype: str
        """
        return self._upgrade_url

    @upgrade_url.setter
    def upgrade_url(self, upgrade_url):
        """Sets the upgrade_url of this ExecuteEdgeUpgradeData.

        URL for the edge to get the upgrade from  # noqa: E501

        :param upgrade_url: The upgrade_url of this ExecuteEdgeUpgradeData.  # noqa: E501
        :type: str
        """
        if upgrade_url is None:
            raise ValueError("Invalid value for `upgrade_url`, must not be `None`")  # noqa: E501

        self._upgrade_url = upgrade_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExecuteEdgeUpgradeData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteEdgeUpgradeData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class HTTPServiceProxy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dns_url': 'str',
        'duration': 'str',
        'id': 'str',
        'name': 'str',
        'password': 'str',
        'project_id': 'str',
        'service_name': 'str',
        'service_namespace': 'str',
        'service_port': 'int',
        'svc_domain_id': 'str',
        'type': 'str',
        'url': 'str',
        'username': 'str'
    }

    attribute_map = {
        'dns_url': 'dnsURL',
        'duration': 'duration',
        'id': 'id',
        'name': 'name',
        'password': 'password',
        'project_id': 'projectId',
        'service_name': 'serviceName',
        'service_namespace': 'serviceNamespace',
        'service_port': 'servicePort',
        'svc_domain_id': 'svcDomainId',
        'type': 'type',
        'url': 'url',
        'username': 'username'
    }

    def __init__(self, dns_url=None, duration=None, id=None, name=None, password=None, project_id=None, service_name=None, service_namespace=None, service_port=None, svc_domain_id=None, type=None, url=None, username=None):  # noqa: E501
        """HTTPServiceProxy - a model defined in Swagger"""  # noqa: E501
        self._dns_url = None
        self._duration = None
        self._id = None
        self._name = None
        self._password = None
        self._project_id = None
        self._service_name = None
        self._service_namespace = None
        self._service_port = None
        self._svc_domain_id = None
        self._type = None
        self._url = None
        self._username = None
        self.discriminator = None
        self.dns_url = dns_url
        self.duration = duration
        if id is not None:
            self.id = id
        self.name = name
        if password is not None:
            self.password = password
        if project_id is not None:
            self.project_id = project_id
        self.service_name = service_name
        if service_namespace is not None:
            self.service_namespace = service_namespace
        self.service_port = service_port
        self.svc_domain_id = svc_domain_id
        self.type = type
        self.url = url
        if username is not None:
            self.username = username

    @property
    def dns_url(self):
        """Gets the dns_url of this HTTPServiceProxy.  # noqa: E501

        DNS URL of the service proxy endpoint Valid only if setupDNS is set to true when creating the service proxy  # noqa: E501

        :return: The dns_url of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._dns_url

    @dns_url.setter
    def dns_url(self, dns_url):
        """Sets the dns_url of this HTTPServiceProxy.

        DNS URL of the service proxy endpoint Valid only if setupDNS is set to true when creating the service proxy  # noqa: E501

        :param dns_url: The dns_url of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if dns_url is None:
            raise ValueError("Invalid value for `dns_url`, must not be `None`")  # noqa: E501

        self._dns_url = dns_url

    @property
    def duration(self):
        """Gets the duration of this HTTPServiceProxy.  # noqa: E501

        Duration of the http service proxy.  # noqa: E501

        :return: The duration of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this HTTPServiceProxy.

        Duration of the http service proxy.  # noqa: E501

        :param duration: The duration of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if duration is None:
            raise ValueError("Invalid value for `duration`, must not be `None`")  # noqa: E501

        self._duration = duration

    @property
    def id(self):
        """Gets the id of this HTTPServiceProxy.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HTTPServiceProxy.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this HTTPServiceProxy.  # noqa: E501

        HTTP service proxy name. Unique within (tenant, service domain)  # noqa: E501

        :return: The name of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HTTPServiceProxy.

        HTTP service proxy name. Unique within (tenant, service domain)  # noqa: E501

        :param name: The name of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def password(self):
        """Gets the password of this HTTPServiceProxy.  # noqa: E501

        Password to login to the service when setupBasicAuth=true.  # noqa: E501

        :return: The password of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this HTTPServiceProxy.

        Password to login to the service when setupBasicAuth=true.  # noqa: E501

        :param password: The password of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def project_id(self):
        """Gets the project_id of this HTTPServiceProxy.  # noqa: E501

        ID of parent project, required when TYPE = PROJECT.  # noqa: E501

        :return: The project_id of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this HTTPServiceProxy.

        ID of parent project, required when TYPE = PROJECT.  # noqa: E501

        :param project_id: The project_id of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def service_name(self):
        """Gets the service_name of this HTTPServiceProxy.  # noqa: E501

        Name of the http service.  # noqa: E501

        :return: The service_name of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """Sets the service_name of this HTTPServiceProxy.

        Name of the http service.  # noqa: E501

        :param service_name: The service_name of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if service_name is None:
            raise ValueError("Invalid value for `service_name`, must not be `None`")  # noqa: E501

        self._service_name = service_name

    @property
    def service_namespace(self):
        """Gets the service_namespace of this HTTPServiceProxy.  # noqa: E501

        Namespace of the http service, required when TYPE = SYSTEM  # noqa: E501

        :return: The service_namespace of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._service_namespace

    @service_namespace.setter
    def service_namespace(self, service_namespace):
        """Sets the service_namespace of this HTTPServiceProxy.

        Namespace of the http service, required when TYPE = SYSTEM  # noqa: E501

        :param service_namespace: The service_namespace of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """

        self._service_namespace = service_namespace

    @property
    def service_port(self):
        """Gets the service_port of this HTTPServiceProxy.  # noqa: E501

        Port of the http service.  # noqa: E501

        :return: The service_port of this HTTPServiceProxy.  # noqa: E501
        :rtype: int
        """
        return self._service_port

    @service_port.setter
    def service_port(self, service_port):
        """Sets the service_port of this HTTPServiceProxy.

        Port of the http service.  # noqa: E501

        :param service_port: The service_port of this HTTPServiceProxy.  # noqa: E501
        :type: int
        """
        if service_port is None:
            raise ValueError("Invalid value for `service_port`, must not be `None`")  # noqa: E501

        self._service_port = service_port

    @property
    def svc_domain_id(self):
        """Gets the svc_domain_id of this HTTPServiceProxy.  # noqa: E501

        ID of the service domain this entity belongs to  # noqa: E501

        :return: The svc_domain_id of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._svc_domain_id

    @svc_domain_id.setter
    def svc_domain_id(self, svc_domain_id):
        """Sets the svc_domain_id of this HTTPServiceProxy.

        ID of the service domain this entity belongs to  # noqa: E501

        :param svc_domain_id: The svc_domain_id of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if svc_domain_id is None:
            raise ValueError("Invalid value for `svc_domain_id`, must not be `None`")  # noqa: E501

        self._svc_domain_id = svc_domain_id

    @property
    def type(self):
        """Gets the type of this HTTPServiceProxy.  # noqa: E501

        Service type for this http proxy.  # noqa: E501

        :return: The type of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this HTTPServiceProxy.

        Service type for this http proxy.  # noqa: E501

        :param type: The type of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["SYSTEM", "PROJECT", "CUSTOM"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def url(self):
        """Gets the url of this HTTPServiceProxy.  # noqa: E501

        URL of the service proxy endpoint  # noqa: E501

        :return: The url of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this HTTPServiceProxy.

        URL of the service proxy endpoint  # noqa: E501

        :param url: The url of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def username(self):
        """Gets the username of this HTTPServiceProxy.  # noqa: E501

        Username to login to the service when setupBasicAuth=true.  # noqa: E501

        :return: The username of this HTTPServiceProxy.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this HTTPServiceProxy.

        Username to login to the service when setupBasicAuth=true.  # noqa: E501

        :param username: The username of this HTTPServiceProxy.  # noqa: E501
        :type: str
        """

        self._username = username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HTTPServiceProxy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HTTPServiceProxy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.category_info import CategoryInfo  # noqa: F401,E501
from kps_api.models.project_user_info import ProjectUserInfo  # noqa: F401,E501


class Project(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_credential_ids': 'list[str]',
        'description': 'str',
        'docker_profile_ids': 'list[str]',
        'edge_ids': 'list[str]',
        'edge_selector_type': 'str',
        'edge_selectors': 'list[CategoryInfo]',
        'id': 'str',
        'name': 'str',
        'privileged': 'bool',
        'users': 'list[ProjectUserInfo]'
    }

    attribute_map = {
        'cloud_credential_ids': 'cloudCredentialIds',
        'description': 'description',
        'docker_profile_ids': 'dockerProfileIds',
        'edge_ids': 'edgeIds',
        'edge_selector_type': 'edgeSelectorType',
        'edge_selectors': 'edgeSelectors',
        'id': 'id',
        'name': 'name',
        'privileged': 'privileged',
        'users': 'users'
    }

    def __init__(self, cloud_credential_ids=None, description=None, docker_profile_ids=None, edge_ids=None, edge_selector_type=None, edge_selectors=None, id=None, name=None, privileged=None, users=None):  # noqa: E501
        """Project - a model defined in Swagger"""  # noqa: E501
        self._cloud_credential_ids = None
        self._description = None
        self._docker_profile_ids = None
        self._edge_ids = None
        self._edge_selector_type = None
        self._edge_selectors = None
        self._id = None
        self._name = None
        self._privileged = None
        self._users = None
        self.discriminator = None
        self.cloud_credential_ids = cloud_credential_ids
        self.description = description
        self.docker_profile_ids = docker_profile_ids
        if edge_ids is not None:
            self.edge_ids = edge_ids
        self.edge_selector_type = edge_selector_type
        if edge_selectors is not None:
            self.edge_selectors = edge_selectors
        if id is not None:
            self.id = id
        self.name = name
        if privileged is not None:
            self.privileged = privileged
        self.users = users

    @property
    def cloud_credential_ids(self):
        """Gets the cloud_credential_ids of this Project.  # noqa: E501

        List of cloud profile credential IDs that the project can access.  # noqa: E501

        :return: The cloud_credential_ids of this Project.  # noqa: E501
        :rtype: list[str]
        """
        return self._cloud_credential_ids

    @cloud_credential_ids.setter
    def cloud_credential_ids(self, cloud_credential_ids):
        """Sets the cloud_credential_ids of this Project.

        List of cloud profile credential IDs that the project can access.  # noqa: E501

        :param cloud_credential_ids: The cloud_credential_ids of this Project.  # noqa: E501
        :type: list[str]
        """
        if cloud_credential_ids is None:
            raise ValueError("Invalid value for `cloud_credential_ids`, must not be `None`")  # noqa: E501

        self._cloud_credential_ids = cloud_credential_ids

    @property
    def description(self):
        """Gets the description of this Project.  # noqa: E501

        Describe the project.  # noqa: E501

        :return: The description of this Project.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Project.

        Describe the project.  # noqa: E501

        :param description: The description of this Project.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def docker_profile_ids(self):
        """Gets the docker_profile_ids of this Project.  # noqa: E501

        List of Docker container registry profile IDs that the project can access.  # noqa: E501

        :return: The docker_profile_ids of this Project.  # noqa: E501
        :rtype: list[str]
        """
        return self._docker_profile_ids

    @docker_profile_ids.setter
    def docker_profile_ids(self, docker_profile_ids):
        """Sets the docker_profile_ids of this Project.

        List of Docker container registry profile IDs that the project can access.  # noqa: E501

        :param docker_profile_ids: The docker_profile_ids of this Project.  # noqa: E501
        :type: list[str]
        """
        if docker_profile_ids is None:
            raise ValueError("Invalid value for `docker_profile_ids`, must not be `None`")  # noqa: E501

        self._docker_profile_ids = docker_profile_ids

    @property
    def edge_ids(self):
        """Gets the edge_ids of this Project.  # noqa: E501

        List of edge IDs for edges in this project. Only relevant when edgeSelectorType === 'Explicit'  # noqa: E501

        :return: The edge_ids of this Project.  # noqa: E501
        :rtype: list[str]
        """
        return self._edge_ids

    @edge_ids.setter
    def edge_ids(self, edge_ids):
        """Sets the edge_ids of this Project.

        List of edge IDs for edges in this project. Only relevant when edgeSelectorType === 'Explicit'  # noqa: E501

        :param edge_ids: The edge_ids of this Project.  # noqa: E501
        :type: list[str]
        """

        self._edge_ids = edge_ids

    @property
    def edge_selector_type(self):
        """Gets the edge_selector_type of this Project.  # noqa: E501

        Type of edge selector: Category or Explicit. Specify whether edges belonging to this project are given by edgeIDs (Explicit) or edgeSelectors (Category).  # noqa: E501

        :return: The edge_selector_type of this Project.  # noqa: E501
        :rtype: str
        """
        return self._edge_selector_type

    @edge_selector_type.setter
    def edge_selector_type(self, edge_selector_type):
        """Sets the edge_selector_type of this Project.

        Type of edge selector: Category or Explicit. Specify whether edges belonging to this project are given by edgeIDs (Explicit) or edgeSelectors (Category).  # noqa: E501

        :param edge_selector_type: The edge_selector_type of this Project.  # noqa: E501
        :type: str
        """
        if edge_selector_type is None:
            raise ValueError("Invalid value for `edge_selector_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Category", "Explicit"]  # noqa: E501
        if edge_selector_type not in allowed_values:
            raise ValueError(
                "Invalid value for `edge_selector_type` ({0}), must be one of {1}"  # noqa: E501
                .format(edge_selector_type, allowed_values)
            )

        self._edge_selector_type = edge_selector_type

    @property
    def edge_selectors(self):
        """Gets the edge_selectors of this Project.  # noqa: E501

        Edge selectors - CategoryInfo list. Only relevant when edgeSelectorType === 'Category'  # noqa: E501

        :return: The edge_selectors of this Project.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._edge_selectors

    @edge_selectors.setter
    def edge_selectors(self, edge_selectors):
        """Sets the edge_selectors of this Project.

        Edge selectors - CategoryInfo list. Only relevant when edgeSelectorType === 'Category'  # noqa: E501

        :param edge_selectors: The edge_selectors of this Project.  # noqa: E501
        :type: list[CategoryInfo]
        """

        self._edge_selectors = edge_selectors

    @property
    def id(self):
        """Gets the id of this Project.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this Project.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Project.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this Project.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Project.  # noqa: E501

        Project name.  # noqa: E501

        :return: The name of this Project.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Project.

        Project name.  # noqa: E501

        :param name: The name of this Project.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def privileged(self):
        """Gets the privileged of this Project.  # noqa: E501

        Privileged projects can use all Kubernetes resources  # noqa: E501

        :return: The privileged of this Project.  # noqa: E501
        :rtype: bool
        """
        return self._privileged

    @privileged.setter
    def privileged(self, privileged):
        """Sets the privileged of this Project.

        Privileged projects can use all Kubernetes resources  # noqa: E501

        :param privileged: The privileged of this Project.  # noqa: E501
        :type: bool
        """

        self._privileged = privileged

    @property
    def users(self):
        """Gets the users of this Project.  # noqa: E501

        List of users who can access the project.  # noqa: E501

        :return: The users of this Project.  # noqa: E501
        :rtype: list[ProjectUserInfo]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this Project.

        List of users who can access the project.  # noqa: E501

        :param users: The users of this Project.  # noqa: E501
        :type: list[ProjectUserInfo]
        """
        if users is None:
            raise ValueError("Invalid value for `users`, must not be `None`")  # noqa: E501

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Project, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Project):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DataSourceFieldInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_type': 'str',
        'mqtt_topic': 'str',
        'name': 'str'
    }

    attribute_map = {
        'field_type': 'fieldType',
        'mqtt_topic': 'mqttTopic',
        'name': 'name'
    }

    def __init__(self, field_type=None, mqtt_topic=None, name=None):  # noqa: E501
        """DataSourceFieldInfo - a model defined in Swagger"""  # noqa: E501
        self._field_type = None
        self._mqtt_topic = None
        self._name = None
        self.discriminator = None
        self.field_type = field_type
        self.mqtt_topic = mqtt_topic
        self.name = name

    @property
    def field_type(self):
        """Gets the field_type of this DataSourceFieldInfo.  # noqa: E501

        Data type for the field. For example, Temperature, Pressure, Custom, and so on. Specify Custom for the entire topic payload. No special extraction is performed. When you specify Custom, Karbon Platform Services might not perform intelligent operations automatically when you specify other fields like Temperature. In the future custom extraction functions for each field might be allowed. DataSource dataType is derived from fieldType of all fields in the data source.  # noqa: E501

        :return: The field_type of this DataSourceFieldInfo.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this DataSourceFieldInfo.

        Data type for the field. For example, Temperature, Pressure, Custom, and so on. Specify Custom for the entire topic payload. No special extraction is performed. When you specify Custom, Karbon Platform Services might not perform intelligent operations automatically when you specify other fields like Temperature. In the future custom extraction functions for each field might be allowed. DataSource dataType is derived from fieldType of all fields in the data source.  # noqa: E501

        :param field_type: The field_type of this DataSourceFieldInfo.  # noqa: E501
        :type: str
        """
        if field_type is None:
            raise ValueError("Invalid value for `field_type`, must not be `None`")  # noqa: E501

        self._field_type = field_type

    @property
    def mqtt_topic(self):
        """Gets the mqtt_topic of this DataSourceFieldInfo.  # noqa: E501

        Topic for the field. The topic specified depends on the protocol in the data source. Specify the mqqtTopic for the MQTT protocol. For the RTSP protocol, the topic is the server endpoint or named protocol stream in the RSTP URL.  # noqa: E501

        :return: The mqtt_topic of this DataSourceFieldInfo.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_topic

    @mqtt_topic.setter
    def mqtt_topic(self, mqtt_topic):
        """Sets the mqtt_topic of this DataSourceFieldInfo.

        Topic for the field. The topic specified depends on the protocol in the data source. Specify the mqqtTopic for the MQTT protocol. For the RTSP protocol, the topic is the server endpoint or named protocol stream in the RSTP URL.  # noqa: E501

        :param mqtt_topic: The mqtt_topic of this DataSourceFieldInfo.  # noqa: E501
        :type: str
        """
        if mqtt_topic is None:
            raise ValueError("Invalid value for `mqtt_topic`, must not be `None`")  # noqa: E501

        self._mqtt_topic = mqtt_topic

    @property
    def name(self):
        """Gets the name of this DataSourceFieldInfo.  # noqa: E501

        A unique name within the the data source.  # noqa: E501

        :return: The name of this DataSourceFieldInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DataSourceFieldInfo.

        A unique name within the the data source.  # noqa: E501

        :param name: The name of this DataSourceFieldInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataSourceFieldInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataSourceFieldInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.user_api_token_api import UserAPITokenApi  # noqa: E501
from kps_api.rest import ApiException


class TestUserAPITokenApi(unittest.TestCase):
    """UserAPITokenApi unit test stubs"""

    def setUp(self):
        self.api = api.user_api_token_api.UserAPITokenApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_api_token_create(self):
        """Test case for user_api_token_create

        Create a user API token.  # noqa: E501
        """
        pass

    def test_user_api_token_delete(self):
        """Test case for user_api_token_delete

        Delete current user API token.  # noqa: E501
        """
        pass

    def test_user_api_token_get(self):
        """Test case for user_api_token_get

        Get current user API tokens.  # noqa: E501
        """
        pass

    def test_user_api_token_list(self):
        """Test case for user_api_token_list

        Get all user API tokens.  # noqa: E501
        """
        pass

    def test_user_api_token_update(self):
        """Test case for user_api_token_update

        Update user API token.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.response_flags import ResponseFlags  # noqa: F401,E501
from kps_api.models.response_hosts import ResponseHosts  # noqa: F401,E501


class ResponseDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'flags': 'ResponseFlags',
        'hosts': 'ResponseHosts'
    }

    attribute_map = {
        'flags': 'flags',
        'hosts': 'hosts'
    }

    def __init__(self, flags=None, hosts=None):  # noqa: E501
        """ResponseDetail - a model defined in Swagger"""  # noqa: E501
        self._flags = None
        self._hosts = None
        self.discriminator = None
        if flags is not None:
            self.flags = flags
        if hosts is not None:
            self.hosts = hosts

    @property
    def flags(self):
        """Gets the flags of this ResponseDetail.  # noqa: E501


        :return: The flags of this ResponseDetail.  # noqa: E501
        :rtype: ResponseFlags
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this ResponseDetail.


        :param flags: The flags of this ResponseDetail.  # noqa: E501
        :type: ResponseFlags
        """

        self._flags = flags

    @property
    def hosts(self):
        """Gets the hosts of this ResponseDetail.  # noqa: E501


        :return: The hosts of this ResponseDetail.  # noqa: E501
        :rtype: ResponseHosts
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this ResponseDetail.


        :param hosts: The hosts of this ResponseDetail.  # noqa: E501
        :type: ResponseHosts
        """

        self._hosts = hosts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.features import Features  # noqa: F401,E501


class ServiceDomainInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'artifacts': 'dict(str, object)',
        'features': 'Features',
        'id': 'str',
        'svc_domain_id': 'str'
    }

    attribute_map = {
        'artifacts': 'artifacts',
        'features': 'features',
        'id': 'id',
        'svc_domain_id': 'svcDomainId'
    }

    def __init__(self, artifacts=None, features=None, id=None, svc_domain_id=None):  # noqa: E501
        """ServiceDomainInfo - a model defined in Swagger"""  # noqa: E501
        self._artifacts = None
        self._features = None
        self._id = None
        self._svc_domain_id = None
        self.discriminator = None
        if artifacts is not None:
            self.artifacts = artifacts
        if features is not None:
            self.features = features
        if id is not None:
            self.id = id
        self.svc_domain_id = svc_domain_id

    @property
    def artifacts(self):
        """Gets the artifacts of this ServiceDomainInfo.  # noqa: E501


        :return: The artifacts of this ServiceDomainInfo.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this ServiceDomainInfo.


        :param artifacts: The artifacts of this ServiceDomainInfo.  # noqa: E501
        :type: dict(str, object)
        """

        self._artifacts = artifacts

    @property
    def features(self):
        """Gets the features of this ServiceDomainInfo.  # noqa: E501


        :return: The features of this ServiceDomainInfo.  # noqa: E501
        :rtype: Features
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this ServiceDomainInfo.


        :param features: The features of this ServiceDomainInfo.  # noqa: E501
        :type: Features
        """

        self._features = features

    @property
    def id(self):
        """Gets the id of this ServiceDomainInfo.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this ServiceDomainInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServiceDomainInfo.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this ServiceDomainInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def svc_domain_id(self):
        """Gets the svc_domain_id of this ServiceDomainInfo.  # noqa: E501

        ID of the service domain this entity belongs to  # noqa: E501

        :return: The svc_domain_id of this ServiceDomainInfo.  # noqa: E501
        :rtype: str
        """
        return self._svc_domain_id

    @svc_domain_id.setter
    def svc_domain_id(self, svc_domain_id):
        """Sets the svc_domain_id of this ServiceDomainInfo.

        ID of the service domain this entity belongs to  # noqa: E501

        :param svc_domain_id: The svc_domain_id of this ServiceDomainInfo.  # noqa: E501
        :type: str
        """
        if svc_domain_id is None:
            raise ValueError("Invalid value for `svc_domain_id`, must not be `None`")  # noqa: E501

        self._svc_domain_id = svc_domain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceDomainInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceDomainInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.cloud_creds import CloudCreds  # noqa: F401,E501


class CloudCredsListResponsePayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'order_by': 'str',
        'order_by_keys': 'list[str]',
        'page_index': 'int',
        'page_size': 'int',
        'result': 'list[CloudCreds]',
        'total_count': 'int'
    }

    attribute_map = {
        'order_by': 'orderBy',
        'order_by_keys': 'orderByKeys',
        'page_index': 'pageIndex',
        'page_size': 'pageSize',
        'result': 'result',
        'total_count': 'totalCount'
    }

    def __init__(self, order_by=None, order_by_keys=None, page_index=None, page_size=None, result=None, total_count=None):  # noqa: E501
        """CloudCredsListResponsePayload - a model defined in Swagger"""  # noqa: E501
        self._order_by = None
        self._order_by_keys = None
        self._page_index = None
        self._page_size = None
        self._result = None
        self._total_count = None
        self.discriminator = None
        if order_by is not None:
            self.order_by = order_by
        if order_by_keys is not None:
            self.order_by_keys = order_by_keys
        self.page_index = page_index
        self.page_size = page_size
        self.result = result
        self.total_count = total_count

    @property
    def order_by(self):
        """Gets the order_by of this CloudCredsListResponsePayload.  # noqa: E501

        Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.  # noqa: E501

        :return: The order_by of this CloudCredsListResponsePayload.  # noqa: E501
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this CloudCredsListResponsePayload.

        Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.  # noqa: E501

        :param order_by: The order_by of this CloudCredsListResponsePayload.  # noqa: E501
        :type: str
        """

        self._order_by = order_by

    @property
    def order_by_keys(self):
        """Gets the order_by_keys of this CloudCredsListResponsePayload.  # noqa: E501

        Keys that can be used in orderBy.  # noqa: E501

        :return: The order_by_keys of this CloudCredsListResponsePayload.  # noqa: E501
        :rtype: list[str]
        """
        return self._order_by_keys

    @order_by_keys.setter
    def order_by_keys(self, order_by_keys):
        """Sets the order_by_keys of this CloudCredsListResponsePayload.

        Keys that can be used in orderBy.  # noqa: E501

        :param order_by_keys: The order_by_keys of this CloudCredsListResponsePayload.  # noqa: E501
        :type: list[str]
        """

        self._order_by_keys = order_by_keys

    @property
    def page_index(self):
        """Gets the page_index of this CloudCredsListResponsePayload.  # noqa: E501

        0-based index of the page to fetch results.  # noqa: E501

        :return: The page_index of this CloudCredsListResponsePayload.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this CloudCredsListResponsePayload.

        0-based index of the page to fetch results.  # noqa: E501

        :param page_index: The page_index of this CloudCredsListResponsePayload.  # noqa: E501
        :type: int
        """
        if page_index is None:
            raise ValueError("Invalid value for `page_index`, must not be `None`")  # noqa: E501

        self._page_index = page_index

    @property
    def page_size(self):
        """Gets the page_size of this CloudCredsListResponsePayload.  # noqa: E501

        Item count of each page.  # noqa: E501

        :return: The page_size of this CloudCredsListResponsePayload.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this CloudCredsListResponsePayload.

        Item count of each page.  # noqa: E501

        :param page_size: The page_size of this CloudCredsListResponsePayload.  # noqa: E501
        :type: int
        """
        if page_size is None:
            raise ValueError("Invalid value for `page_size`, must not be `None`")  # noqa: E501

        self._page_size = page_size

    @property
    def result(self):
        """Gets the result of this CloudCredsListResponsePayload.  # noqa: E501

        list of cloud profiles  # noqa: E501

        :return: The result of this CloudCredsListResponsePayload.  # noqa: E501
        :rtype: list[CloudCreds]
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this CloudCredsListResponsePayload.

        list of cloud profiles  # noqa: E501

        :param result: The result of this CloudCredsListResponsePayload.  # noqa: E501
        :type: list[CloudCreds]
        """
        if result is None:
            raise ValueError("Invalid value for `result`, must not be `None`")  # noqa: E501

        self._result = result

    @property
    def total_count(self):
        """Gets the total_count of this CloudCredsListResponsePayload.  # noqa: E501

        Count of all items matching the query.  # noqa: E501

        :return: The total_count of this CloudCredsListResponsePayload.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this CloudCredsListResponsePayload.

        Count of all items matching the query.  # noqa: E501

        :param total_count: The total_count of this CloudCredsListResponsePayload.  # noqa: E501
        :type: int
        """
        if total_count is None:
            raise ValueError("Invalid value for `total_count`, must not be `None`")  # noqa: E501

        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudCredsListResponsePayload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudCredsListResponsePayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Iter8TrafficControl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'algorithm': 'str',
        'interval': 'str',
        'max_iterations': 'int',
        'max_traffic_percentage': 'float',
        'traffic_step_size': 'float'
    }

    attribute_map = {
        'algorithm': 'algorithm',
        'interval': 'interval',
        'max_iterations': 'maxIterations',
        'max_traffic_percentage': 'maxTrafficPercentage',
        'traffic_step_size': 'trafficStepSize'
    }

    def __init__(self, algorithm=None, interval=None, max_iterations=None, max_traffic_percentage=None, traffic_step_size=None):  # noqa: E501
        """Iter8TrafficControl - a model defined in Swagger"""  # noqa: E501
        self._algorithm = None
        self._interval = None
        self._max_iterations = None
        self._max_traffic_percentage = None
        self._traffic_step_size = None
        self.discriminator = None
        if algorithm is not None:
            self.algorithm = algorithm
        if interval is not None:
            self.interval = interval
        if max_iterations is not None:
            self.max_iterations = max_iterations
        if max_traffic_percentage is not None:
            self.max_traffic_percentage = max_traffic_percentage
        if traffic_step_size is not None:
            self.traffic_step_size = traffic_step_size

    @property
    def algorithm(self):
        """Gets the algorithm of this Iter8TrafficControl.  # noqa: E501


        :return: The algorithm of this Iter8TrafficControl.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this Iter8TrafficControl.


        :param algorithm: The algorithm of this Iter8TrafficControl.  # noqa: E501
        :type: str
        """

        self._algorithm = algorithm

    @property
    def interval(self):
        """Gets the interval of this Iter8TrafficControl.  # noqa: E501


        :return: The interval of this Iter8TrafficControl.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this Iter8TrafficControl.


        :param interval: The interval of this Iter8TrafficControl.  # noqa: E501
        :type: str
        """

        self._interval = interval

    @property
    def max_iterations(self):
        """Gets the max_iterations of this Iter8TrafficControl.  # noqa: E501


        :return: The max_iterations of this Iter8TrafficControl.  # noqa: E501
        :rtype: int
        """
        return self._max_iterations

    @max_iterations.setter
    def max_iterations(self, max_iterations):
        """Sets the max_iterations of this Iter8TrafficControl.


        :param max_iterations: The max_iterations of this Iter8TrafficControl.  # noqa: E501
        :type: int
        """

        self._max_iterations = max_iterations

    @property
    def max_traffic_percentage(self):
        """Gets the max_traffic_percentage of this Iter8TrafficControl.  # noqa: E501


        :return: The max_traffic_percentage of this Iter8TrafficControl.  # noqa: E501
        :rtype: float
        """
        return self._max_traffic_percentage

    @max_traffic_percentage.setter
    def max_traffic_percentage(self, max_traffic_percentage):
        """Sets the max_traffic_percentage of this Iter8TrafficControl.


        :param max_traffic_percentage: The max_traffic_percentage of this Iter8TrafficControl.  # noqa: E501
        :type: float
        """

        self._max_traffic_percentage = max_traffic_percentage

    @property
    def traffic_step_size(self):
        """Gets the traffic_step_size of this Iter8TrafficControl.  # noqa: E501


        :return: The traffic_step_size of this Iter8TrafficControl.  # noqa: E501
        :rtype: float
        """
        return self._traffic_step_size

    @traffic_step_size.setter
    def traffic_step_size(self, traffic_step_size):
        """Sets the traffic_step_size of this Iter8TrafficControl.


        :param traffic_step_size: The traffic_step_size of this Iter8TrafficControl.  # noqa: E501
        :type: float
        """

        self._traffic_step_size = traffic_step_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Iter8TrafficControl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Iter8TrafficControl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.data_source_ifc_ports import DataSourceIfcPorts  # noqa: F401,E501


class DataSourceIfcInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ifc_class': 'str',
        'ifc_driver_id': 'str',
        'ifc_img': 'str',
        'ifc_kind': 'str',
        'ifc_ports': 'list[DataSourceIfcPorts]',
        'ifc_project_id': 'str',
        'ifc_protocol': 'str'
    }

    attribute_map = {
        'ifc_class': 'ifcClass',
        'ifc_driver_id': 'ifcDriverId',
        'ifc_img': 'ifcImg',
        'ifc_kind': 'ifcKind',
        'ifc_ports': 'ifcPorts',
        'ifc_project_id': 'ifcProjectId',
        'ifc_protocol': 'ifcProtocol'
    }

    def __init__(self, ifc_class=None, ifc_driver_id=None, ifc_img=None, ifc_kind=None, ifc_ports=None, ifc_project_id=None, ifc_protocol=None):  # noqa: E501
        """DataSourceIfcInfo - a model defined in Swagger"""  # noqa: E501
        self._ifc_class = None
        self._ifc_driver_id = None
        self._ifc_img = None
        self._ifc_kind = None
        self._ifc_ports = None
        self._ifc_project_id = None
        self._ifc_protocol = None
        self.discriminator = None
        self.ifc_class = ifc_class
        self.ifc_driver_id = ifc_driver_id
        self.ifc_img = ifc_img
        self.ifc_kind = ifc_kind
        if ifc_ports is not None:
            self.ifc_ports = ifc_ports
        if ifc_project_id is not None:
            self.ifc_project_id = ifc_project_id
        self.ifc_protocol = ifc_protocol

    @property
    def ifc_class(self):
        """Gets the ifc_class of this DataSourceIfcInfo.  # noqa: E501

        Class of the data source DataInterface or Legacy  # noqa: E501

        :return: The ifc_class of this DataSourceIfcInfo.  # noqa: E501
        :rtype: str
        """
        return self._ifc_class

    @ifc_class.setter
    def ifc_class(self, ifc_class):
        """Sets the ifc_class of this DataSourceIfcInfo.

        Class of the data source DataInterface or Legacy  # noqa: E501

        :param ifc_class: The ifc_class of this DataSourceIfcInfo.  # noqa: E501
        :type: str
        """
        if ifc_class is None:
            raise ValueError("Invalid value for `ifc_class`, must not be `None`")  # noqa: E501
        allowed_values = ["DATAINTERFACE", "LEGACY"]  # noqa: E501
        if ifc_class not in allowed_values:
            raise ValueError(
                "Invalid value for `ifc_class` ({0}), must be one of {1}"  # noqa: E501
                .format(ifc_class, allowed_values)
            )

        self._ifc_class = ifc_class

    @property
    def ifc_driver_id(self):
        """Gets the ifc_driver_id of this DataSourceIfcInfo.  # noqa: E501

        Driver from which this data source is derived.  # noqa: E501

        :return: The ifc_driver_id of this DataSourceIfcInfo.  # noqa: E501
        :rtype: str
        """
        return self._ifc_driver_id

    @ifc_driver_id.setter
    def ifc_driver_id(self, ifc_driver_id):
        """Sets the ifc_driver_id of this DataSourceIfcInfo.

        Driver from which this data source is derived.  # noqa: E501

        :param ifc_driver_id: The ifc_driver_id of this DataSourceIfcInfo.  # noqa: E501
        :type: str
        """
        if ifc_driver_id is None:
            raise ValueError("Invalid value for `ifc_driver_id`, must not be `None`")  # noqa: E501

        self._ifc_driver_id = ifc_driver_id

    @property
    def ifc_img(self):
        """Gets the ifc_img of this DataSourceIfcInfo.  # noqa: E501

        The docker img that includes the data source  # noqa: E501

        :return: The ifc_img of this DataSourceIfcInfo.  # noqa: E501
        :rtype: str
        """
        return self._ifc_img

    @ifc_img.setter
    def ifc_img(self, ifc_img):
        """Sets the ifc_img of this DataSourceIfcInfo.

        The docker img that includes the data source  # noqa: E501

        :param ifc_img: The ifc_img of this DataSourceIfcInfo.  # noqa: E501
        :type: str
        """
        if ifc_img is None:
            raise ValueError("Invalid value for `ifc_img`, must not be `None`")  # noqa: E501

        self._ifc_img = ifc_img

    @property
    def ifc_kind(self):
        """Gets the ifc_kind of this DataSourceIfcInfo.  # noqa: E501

        Kind of data source IN, OUT, PIPE (bidirectional)  # noqa: E501

        :return: The ifc_kind of this DataSourceIfcInfo.  # noqa: E501
        :rtype: str
        """
        return self._ifc_kind

    @ifc_kind.setter
    def ifc_kind(self, ifc_kind):
        """Sets the ifc_kind of this DataSourceIfcInfo.

        Kind of data source IN, OUT, PIPE (bidirectional)  # noqa: E501

        :param ifc_kind: The ifc_kind of this DataSourceIfcInfo.  # noqa: E501
        :type: str
        """
        if ifc_kind is None:
            raise ValueError("Invalid value for `ifc_kind`, must not be `None`")  # noqa: E501
        allowed_values = ["IN", "OUT", "PIPE"]  # noqa: E501
        if ifc_kind not in allowed_values:
            raise ValueError(
                "Invalid value for `ifc_kind` ({0}), must be one of {1}"  # noqa: E501
                .format(ifc_kind, allowed_values)
            )

        self._ifc_kind = ifc_kind

    @property
    def ifc_ports(self):
        """Gets the ifc_ports of this DataSourceIfcInfo.  # noqa: E501

        Any ports that will be opened and used by this datasource  # noqa: E501

        :return: The ifc_ports of this DataSourceIfcInfo.  # noqa: E501
        :rtype: list[DataSourceIfcPorts]
        """
        return self._ifc_ports

    @ifc_ports.setter
    def ifc_ports(self, ifc_ports):
        """Sets the ifc_ports of this DataSourceIfcInfo.

        Any ports that will be opened and used by this datasource  # noqa: E501

        :param ifc_ports: The ifc_ports of this DataSourceIfcInfo.  # noqa: E501
        :type: list[DataSourceIfcPorts]
        """

        self._ifc_ports = ifc_ports

    @property
    def ifc_project_id(self):
        """Gets the ifc_project_id of this DataSourceIfcInfo.  # noqa: E501

        The project that contains this data source  # noqa: E501

        :return: The ifc_project_id of this DataSourceIfcInfo.  # noqa: E501
        :rtype: str
        """
        return self._ifc_project_id

    @ifc_project_id.setter
    def ifc_project_id(self, ifc_project_id):
        """Sets the ifc_project_id of this DataSourceIfcInfo.

        The project that contains this data source  # noqa: E501

        :param ifc_project_id: The ifc_project_id of this DataSourceIfcInfo.  # noqa: E501
        :type: str
        """

        self._ifc_project_id = ifc_project_id

    @property
    def ifc_protocol(self):
        """Gets the ifc_protocol of this DataSourceIfcInfo.  # noqa: E501

        Primary protocol that this data source implements  # noqa: E501

        :return: The ifc_protocol of this DataSourceIfcInfo.  # noqa: E501
        :rtype: str
        """
        return self._ifc_protocol

    @ifc_protocol.setter
    def ifc_protocol(self, ifc_protocol):
        """Sets the ifc_protocol of this DataSourceIfcInfo.

        Primary protocol that this data source implements  # noqa: E501

        :param ifc_protocol: The ifc_protocol of this DataSourceIfcInfo.  # noqa: E501
        :type: str
        """
        if ifc_protocol is None:
            raise ValueError("Invalid value for `ifc_protocol`, must not be `None`")  # noqa: E501

        self._ifc_protocol = ifc_protocol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataSourceIfcInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataSourceIfcInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.tenant_profile import TenantProfile  # noqa: F401,E501


class Tenant(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'external_id': 'str',
        'id': 'str',
        'name': 'str',
        'profile': 'TenantProfile',
        'token': 'str',
        'version': 'float'
    }

    attribute_map = {
        'description': 'description',
        'external_id': 'externalId',
        'id': 'id',
        'name': 'name',
        'profile': 'profile',
        'token': 'token',
        'version': 'version'
    }

    def __init__(self, description=None, external_id=None, id=None, name=None, profile=None, token=None, version=None):  # noqa: E501
        """Tenant - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._external_id = None
        self._id = None
        self._name = None
        self._profile = None
        self._token = None
        self._version = None
        self.discriminator = None
        if description is not None:
            self.description = description
        self.external_id = external_id
        self.id = id
        self.name = name
        if profile is not None:
            self.profile = profile
        self.token = token
        if version is not None:
            self.version = version

    @property
    def description(self):
        """Gets the description of this Tenant.  # noqa: E501

        Tenant description. Up to 200 characters.  # noqa: E501

        :return: The description of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Tenant.

        Tenant description. Up to 200 characters.  # noqa: E501

        :param description: The description of this Tenant.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def external_id(self):
        """Gets the external_id of this Tenant.  # noqa: E501

        Unique tenant ID returned by my.nutanix.com.  # noqa: E501

        :return: The external_id of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Tenant.

        Unique tenant ID returned by my.nutanix.com.  # noqa: E501

        :param external_id: The external_id of this Tenant.  # noqa: E501
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")  # noqa: E501

        self._external_id = external_id

    @property
    def id(self):
        """Gets the id of this Tenant.  # noqa: E501

        Unique ID to identify the tenant, which. can be supplied during create or DB generated. For Nice we will have fixed tenant id such as tenant-id-waldot tenant-id-rocket-blue  # noqa: E501

        :return: The id of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Tenant.

        Unique ID to identify the tenant, which. can be supplied during create or DB generated. For Nice we will have fixed tenant id such as tenant-id-waldot tenant-id-rocket-blue  # noqa: E501

        :param id: The id of this Tenant.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Tenant.  # noqa: E501

        Tenant name. For example, WalDot, Rocket Blue, and so on. Up to 200 characters.  # noqa: E501

        :return: The name of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Tenant.

        Tenant name. For example, WalDot, Rocket Blue, and so on. Up to 200 characters.  # noqa: E501

        :param name: The name of this Tenant.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def profile(self):
        """Gets the profile of this Tenant.  # noqa: E501


        :return: The profile of this Tenant.  # noqa: E501
        :rtype: TenantProfile
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this Tenant.


        :param profile: The profile of this Tenant.  # noqa: E501
        :type: TenantProfile
        """

        self._profile = profile

    @property
    def token(self):
        """Gets the token of this Tenant.  # noqa: E501

        Unique token for a tenant. Used in authentication.  # noqa: E501

        :return: The token of this Tenant.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Tenant.

        Unique token for a tenant. Used in authentication.  # noqa: E501

        :param token: The token of this Tenant.  # noqa: E501
        :type: str
        """
        if token is None:
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501

        self._token = token

    @property
    def version(self):
        """Gets the version of this Tenant.  # noqa: E501

        Version number of object maintained by DB. Not currently used.  # noqa: E501

        :return: The version of this Tenant.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Tenant.

        Version number of object maintained by DB. Not currently used.  # noqa: E501

        :param version: The version of this Tenant.  # noqa: E501
        :type: float
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Tenant, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tenant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.runtime_environment_api import RuntimeEnvironmentApi  # noqa: E501
from kps_api.rest import ApiException


class TestRuntimeEnvironmentApi(unittest.TestCase):
    """RuntimeEnvironmentApi unit test stubs"""

    def setUp(self):
        self.api = api.runtime_environment_api.RuntimeEnvironmentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_project_get_runtime_environments(self):
        """Test case for project_get_runtime_environments

        Gets runtime environments for a project by project ID.  # noqa: E501
        """
        pass

    def test_runtime_environment_create(self):
        """Test case for runtime_environment_create

        Create a runtime environment for functions.  # noqa: E501
        """
        pass

    def test_runtime_environment_delete(self):
        """Test case for runtime_environment_delete

        Delete a runtime environment by its ID.  # noqa: E501
        """
        pass

    def test_runtime_environment_get(self):
        """Test case for runtime_environment_get

        Get a runtime environment by its ID.  # noqa: E501
        """
        pass

    def test_runtime_environment_list(self):
        """Test case for runtime_environment_list

        Get runtime environments.  # noqa: E501
        """
        pass

    def test_runtime_environment_update(self):
        """Test case for runtime_environment_update

        Update the runtime environment by its ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.connector_class import ConnectorClass  # noqa: F401,E501
from kps_api.models.connector_config import ConnectorConfig  # noqa: F401,E501
from kps_api.models.connector_instance import ConnectorInstance  # noqa: F401,E501
from kps_api.models.connector_stream import ConnectorStream  # noqa: F401,E501


class ConnectorInstanceInventory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_class': 'ConnectorClass',
        'configs': 'list[ConnectorConfig]',
        'doc': 'ConnectorInstance',
        'id': 'str',
        'streams': 'list[ConnectorStream]',
        'yaml_data': 'str'
    }

    attribute_map = {
        '_class': 'class',
        'configs': 'configs',
        'doc': 'doc',
        'id': 'id',
        'streams': 'streams',
        'yaml_data': 'yamlData'
    }

    def __init__(self, _class=None, configs=None, doc=None, id=None, streams=None, yaml_data=None):  # noqa: E501
        """ConnectorInstanceInventory - a model defined in Swagger"""  # noqa: E501
        self.__class = None
        self._configs = None
        self._doc = None
        self._id = None
        self._streams = None
        self._yaml_data = None
        self.discriminator = None
        self._class = _class
        self.configs = configs
        self.doc = doc
        if id is not None:
            self.id = id
        self.streams = streams
        self.yaml_data = yaml_data

    @property
    def _class(self):
        """Gets the _class of this ConnectorInstanceInventory.  # noqa: E501


        :return: The _class of this ConnectorInstanceInventory.  # noqa: E501
        :rtype: ConnectorClass
        """
        return self.__class

    @_class.setter
    def _class(self, _class):
        """Sets the _class of this ConnectorInstanceInventory.


        :param _class: The _class of this ConnectorInstanceInventory.  # noqa: E501
        :type: ConnectorClass
        """
        if _class is None:
            raise ValueError("Invalid value for `_class`, must not be `None`")  # noqa: E501

        self.__class = _class

    @property
    def configs(self):
        """Gets the configs of this ConnectorInstanceInventory.  # noqa: E501


        :return: The configs of this ConnectorInstanceInventory.  # noqa: E501
        :rtype: list[ConnectorConfig]
        """
        return self._configs

    @configs.setter
    def configs(self, configs):
        """Sets the configs of this ConnectorInstanceInventory.


        :param configs: The configs of this ConnectorInstanceInventory.  # noqa: E501
        :type: list[ConnectorConfig]
        """
        if configs is None:
            raise ValueError("Invalid value for `configs`, must not be `None`")  # noqa: E501

        self._configs = configs

    @property
    def doc(self):
        """Gets the doc of this ConnectorInstanceInventory.  # noqa: E501


        :return: The doc of this ConnectorInstanceInventory.  # noqa: E501
        :rtype: ConnectorInstance
        """
        return self._doc

    @doc.setter
    def doc(self, doc):
        """Sets the doc of this ConnectorInstanceInventory.


        :param doc: The doc of this ConnectorInstanceInventory.  # noqa: E501
        :type: ConnectorInstance
        """
        if doc is None:
            raise ValueError("Invalid value for `doc`, must not be `None`")  # noqa: E501

        self._doc = doc

    @property
    def id(self):
        """Gets the id of this ConnectorInstanceInventory.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this ConnectorInstanceInventory.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectorInstanceInventory.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this ConnectorInstanceInventory.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def streams(self):
        """Gets the streams of this ConnectorInstanceInventory.  # noqa: E501


        :return: The streams of this ConnectorInstanceInventory.  # noqa: E501
        :rtype: list[ConnectorStream]
        """
        return self._streams

    @streams.setter
    def streams(self, streams):
        """Sets the streams of this ConnectorInstanceInventory.


        :param streams: The streams of this ConnectorInstanceInventory.  # noqa: E501
        :type: list[ConnectorStream]
        """
        if streams is None:
            raise ValueError("Invalid value for `streams`, must not be `None`")  # noqa: E501

        self._streams = streams

    @property
    def yaml_data(self):
        """Gets the yaml_data of this ConnectorInstanceInventory.  # noqa: E501


        :return: The yaml_data of this ConnectorInstanceInventory.  # noqa: E501
        :rtype: str
        """
        return self._yaml_data

    @yaml_data.setter
    def yaml_data(self, yaml_data):
        """Sets the yaml_data of this ConnectorInstanceInventory.


        :param yaml_data: The yaml_data of this ConnectorInstanceInventory.  # noqa: E501
        :type: str
        """
        if yaml_data is None:
            raise ValueError("Invalid value for `yaml_data`, must not be `None`")  # noqa: E501

        self._yaml_data = yaml_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConnectorInstanceInventory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorInstanceInventory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Iter8Metric(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'absent_value': 'str',
        'is_counter': 'bool',
        'query_template': 'str',
        'sample_size_template': 'str'
    }

    attribute_map = {
        'absent_value': 'absent_value',
        'is_counter': 'is_counter',
        'query_template': 'query_template',
        'sample_size_template': 'sample_size_template'
    }

    def __init__(self, absent_value=None, is_counter=None, query_template=None, sample_size_template=None):  # noqa: E501
        """Iter8Metric - a model defined in Swagger"""  # noqa: E501
        self._absent_value = None
        self._is_counter = None
        self._query_template = None
        self._sample_size_template = None
        self.discriminator = None
        if absent_value is not None:
            self.absent_value = absent_value
        if is_counter is not None:
            self.is_counter = is_counter
        if query_template is not None:
            self.query_template = query_template
        if sample_size_template is not None:
            self.sample_size_template = sample_size_template

    @property
    def absent_value(self):
        """Gets the absent_value of this Iter8Metric.  # noqa: E501


        :return: The absent_value of this Iter8Metric.  # noqa: E501
        :rtype: str
        """
        return self._absent_value

    @absent_value.setter
    def absent_value(self, absent_value):
        """Sets the absent_value of this Iter8Metric.


        :param absent_value: The absent_value of this Iter8Metric.  # noqa: E501
        :type: str
        """

        self._absent_value = absent_value

    @property
    def is_counter(self):
        """Gets the is_counter of this Iter8Metric.  # noqa: E501


        :return: The is_counter of this Iter8Metric.  # noqa: E501
        :rtype: bool
        """
        return self._is_counter

    @is_counter.setter
    def is_counter(self, is_counter):
        """Sets the is_counter of this Iter8Metric.


        :param is_counter: The is_counter of this Iter8Metric.  # noqa: E501
        :type: bool
        """

        self._is_counter = is_counter

    @property
    def query_template(self):
        """Gets the query_template of this Iter8Metric.  # noqa: E501


        :return: The query_template of this Iter8Metric.  # noqa: E501
        :rtype: str
        """
        return self._query_template

    @query_template.setter
    def query_template(self, query_template):
        """Sets the query_template of this Iter8Metric.


        :param query_template: The query_template of this Iter8Metric.  # noqa: E501
        :type: str
        """

        self._query_template = query_template

    @property
    def sample_size_template(self):
        """Gets the sample_size_template of this Iter8Metric.  # noqa: E501


        :return: The sample_size_template of this Iter8Metric.  # noqa: E501
        :rtype: str
        """
        return self._sample_size_template

    @sample_size_template.setter
    def sample_size_template(self, sample_size_template):
        """Sets the sample_size_template of this Iter8Metric.


        :param sample_size_template: The sample_size_template of this Iter8Metric.  # noqa: E501
        :type: str
        """

        self._sample_size_template = sample_size_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Iter8Metric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Iter8Metric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class JaegerInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'integration': 'bool',
        'namespace_selector': 'bool',
        'url': 'str',
        'white_list_istio_system': 'list[str]'
    }

    attribute_map = {
        'enabled': 'enabled',
        'integration': 'integration',
        'namespace_selector': 'namespaceSelector',
        'url': 'url',
        'white_list_istio_system': 'whiteListIstioSystem'
    }

    def __init__(self, enabled=None, integration=None, namespace_selector=None, url=None, white_list_istio_system=None):  # noqa: E501
        """JaegerInfo - a model defined in Swagger"""  # noqa: E501
        self._enabled = None
        self._integration = None
        self._namespace_selector = None
        self._url = None
        self._white_list_istio_system = None
        self.discriminator = None
        if enabled is not None:
            self.enabled = enabled
        if integration is not None:
            self.integration = integration
        if namespace_selector is not None:
            self.namespace_selector = namespace_selector
        if url is not None:
            self.url = url
        if white_list_istio_system is not None:
            self.white_list_istio_system = white_list_istio_system

    @property
    def enabled(self):
        """Gets the enabled of this JaegerInfo.  # noqa: E501


        :return: The enabled of this JaegerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this JaegerInfo.


        :param enabled: The enabled of this JaegerInfo.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def integration(self):
        """Gets the integration of this JaegerInfo.  # noqa: E501


        :return: The integration of this JaegerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._integration

    @integration.setter
    def integration(self, integration):
        """Sets the integration of this JaegerInfo.


        :param integration: The integration of this JaegerInfo.  # noqa: E501
        :type: bool
        """

        self._integration = integration

    @property
    def namespace_selector(self):
        """Gets the namespace_selector of this JaegerInfo.  # noqa: E501


        :return: The namespace_selector of this JaegerInfo.  # noqa: E501
        :rtype: bool
        """
        return self._namespace_selector

    @namespace_selector.setter
    def namespace_selector(self, namespace_selector):
        """Sets the namespace_selector of this JaegerInfo.


        :param namespace_selector: The namespace_selector of this JaegerInfo.  # noqa: E501
        :type: bool
        """

        self._namespace_selector = namespace_selector

    @property
    def url(self):
        """Gets the url of this JaegerInfo.  # noqa: E501


        :return: The url of this JaegerInfo.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this JaegerInfo.


        :param url: The url of this JaegerInfo.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def white_list_istio_system(self):
        """Gets the white_list_istio_system of this JaegerInfo.  # noqa: E501


        :return: The white_list_istio_system of this JaegerInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._white_list_istio_system

    @white_list_istio_system.setter
    def white_list_istio_system(self, white_list_istio_system):
        """Sets the white_list_istio_system of this JaegerInfo.


        :param white_list_istio_system: The white_list_istio_system of this JaegerInfo.  # noqa: E501
        :type: list[str]
        """

        self._white_list_istio_system = white_list_istio_system

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JaegerInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JaegerInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
